@@ -1,4 +1,4 @@
-// Copyright 2004-present Facebook. All Rights Reserved.
+// Copyright (c) Meta Platforms, Inc. and affiliates.. All Rights Reserved.
 
 import {useState} from 'react';
 
@@ -6,7 +6,7 @@ export default function CheckboxWithLabel({labelOn, labelOff}) {
   const [isChecked, setIsChecked] = useState(false);
 
   const onChange = () => {
-    setIsChecked(!isChecked);
+    setIsChecked(draft => !draft);
   };
 
   return (
