@@ -1,12 +1,11 @@
-// Copyright 2004-present Facebook. All Rights Reserved.
+// Copyright (c) Meta Platforms, Inc. and affiliates.. All Rights Reserved.
 
 'use strict';
 
 import renderer from 'react-test-renderer';
 import Clock from '../Clock';
 
-jest.useFakeTimers();
-Date.now = jest.fn(() => 1482363367071);
+jest.useFakeTimers().setSystemTime(1482363367071);
 
 it('renders correctly', () => {
   const tree = renderer.create(<Clock />).toJSON();
