@@ -1,5 +1,5 @@
 /**
- * Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.
+ * Copyright (c) Meta Platforms, Inc. and affiliates.
  *
  * This source code is licensed under the MIT license found in the
  * LICENSE file in the root directory of this source tree.
@@ -10,4 +10,4 @@ export {equals, isA} from './jasmineUtils';
 export type {EqualsFunction} from './jasmineUtils';
 export * from './utils';
 
-export type {Tester} from './types';
+export type {Tester, TesterContext} from './types';
