@@ -1,5 +1,5 @@
 /**
- * Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.
+ * Copyright (c) Meta Platforms, Inc. and affiliates.
  *
  * This source code is licensed under the MIT license found in the
  * LICENSE file in the root directory of this source tree.
@@ -116,10 +116,12 @@ export const initialOptions: Config.InitialOptions = {
   notifyMode: 'failure-change',
   onlyChanged: false,
   onlyFailures: false,
+  openHandlesTimeout: 1000,
   passWithNoTests: false,
   preset: 'react-native',
   prettierPath: '<rootDir>/node_modules/prettier',
   projects: ['project-a', 'project-b/'],
+  randomize: false,
   reporters: [
     'default',
     'custom-reporter-1',
@@ -186,6 +188,7 @@ export const initialOptions: Config.InitialOptions = {
   ],
   watchman: true,
   workerIdleMemoryLimit: multipleValidOptions(0.2, '50%'),
+  workerThreads: true,
 };
 
 export const initialProjectOptions: Config.InitialProjectOptions = {
@@ -193,6 +196,8 @@ export const initialProjectOptions: Config.InitialProjectOptions = {
   cache: true,
   cacheDirectory: '/tmp/user/jest',
   clearMocks: false,
+  collectCoverageFrom: ['src', '!public'],
+  coverageDirectory: 'coverage',
   coveragePathIgnorePatterns: [NODE_MODULES_REGEXP],
   dependencyExtractor: '<rootDir>/dependencyExtractor.js',
   detectLeaks: false,
@@ -261,6 +266,7 @@ export const initialProjectOptions: Config.InitialProjectOptions = {
   },
   modulePathIgnorePatterns: ['<rootDir>/build/'],
   modulePaths: ['/shared/vendor/modules'],
+  openHandlesTimeout: 1000,
   preset: 'react-native',
   prettierPath: '<rootDir>/node_modules/prettier',
   resetMocks: false,
