@@ -1,5 +1,5 @@
 /**
- * Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.
+ * Copyright (c) Meta Platforms, Inc. and affiliates.
  *
  * This source code is licensed under the MIT license found in the
  * LICENSE file in the root directory of this source tree.
@@ -98,6 +98,10 @@ expectError(jest.enableAutomock('moduleName'));
 expectType<typeof jest>(jest.isolateModules(() => {}));
 expectError(jest.isolateModules());
 
+expectType<Promise<void>>(jest.isolateModulesAsync(async () => {}));
+expectError(jest.isolateModulesAsync(() => {}));
+expectError(jest.isolateModulesAsync());
+
 expectType<typeof jest>(jest.mock('moduleName'));
 expectType<typeof jest>(jest.mock('moduleName', jest.fn()));
 expectType<typeof jest>(
@@ -262,6 +266,8 @@ expectType<ModuleMocker['fn']>(jest.fn);
 
 expectType<ModuleMocker['spyOn']>(jest.spyOn);
 
+expectType<ModuleMocker['replaceProperty']>(jest.replaceProperty);
+
 // Mock<T>
 
 expectType<Mock<() => boolean>>({} as jest.Mock<() => boolean>);
@@ -408,7 +414,7 @@ expectType<[]>(mockObjectB.methodA.mock.calls[0]);
 expectType<[b: string]>(mockObjectB.methodB.mock.calls[0]);
 expectType<[c: number]>(mockObjectB.methodC.mock.calls[0]);
 
-expectError<[t: number]>(mockObjectB.one.more.time.mock.calls[0]);
+expectError(mockObjectB.one.more.time.mock.calls[0]);
 
 expectType<[one: string, two?: boolean]>(mockObjectB.SomeClass.mock.calls[0]);
 expectType<[]>(mockObjectB.SomeClass.prototype.methodA.mock.calls[0]);
@@ -416,10 +422,8 @@ expectType<[a: string, b?: number]>(
   mockObjectB.SomeClass.prototype.methodB.mock.calls[0],
 );
 
-expectError<[]>(mockObjectB.someClassInstance.methodA.mock.calls[0]);
-expectError<[a: string, b?: number]>(
-  mockObjectB.someClassInstance.methodB.mock.calls[0],
-);
+expectError(mockObjectB.someClassInstance.methodA.mock.calls[0]);
+expectError(mockObjectB.someClassInstance.methodB.mock.calls[0]);
 
 expectError(mockObjectB.methodA.mockReturnValue(123));
 expectError(mockObjectB.methodA.mockImplementation((a: number) => 123));
@@ -443,6 +447,12 @@ expectError(
 
 expectAssignable<typeof someObject>(mockObjectB);
 
+// Replaced
+
+expectAssignable<jest.Replaced<number>>(
+  jest.replaceProperty(someObject, 'propertyA', 123),
+);
+
 // Spied
 
 expectAssignable<jest.Spied<typeof someObject.methodA>>(
@@ -476,10 +486,17 @@ expectAssignable<jest.SpiedSetter<typeof someObject.propertyC>>(
 expectType<void>(jest.advanceTimersByTime(6000));
 expectError(jest.advanceTimersByTime());
 
+expectType<Promise<void>>(jest.advanceTimersByTimeAsync(6000));
+expectError(jest.advanceTimersByTimeAsync());
+
 expectType<void>(jest.advanceTimersToNextTimer());
 expectType<void>(jest.advanceTimersToNextTimer(2));
 expectError(jest.advanceTimersToNextTimer('2'));
 
+expectType<Promise<void>>(jest.advanceTimersToNextTimerAsync());
+expectType<Promise<void>>(jest.advanceTimersToNextTimerAsync(2));
+expectError(jest.advanceTimersToNextTimerAsync('2'));
+
 expectType<void>(jest.clearAllTimers());
 expectError(jest.clearAllTimers(false));
 
@@ -501,9 +518,15 @@ expectError(jest.runAllTicks(true));
 expectType<void>(jest.runAllTimers());
 expectError(jest.runAllTimers(false));
 
+expectType<Promise<void>>(jest.runAllTimersAsync());
+expectError(jest.runAllTimersAsync(false));
+
 expectType<void>(jest.runOnlyPendingTimers());
 expectError(jest.runOnlyPendingTimers(true));
 
+expectType<Promise<void>>(jest.runOnlyPendingTimersAsync());
+expectError(jest.runOnlyPendingTimersAsync(true));
+
 expectType<void>(jest.setSystemTime());
 expectType<void>(jest.setSystemTime(1483228800000));
 expectType<void>(jest.setSystemTime(Date.now()));
@@ -575,3 +598,6 @@ expectError(jest.setTimeout());
 
 expectType<number>(jest.getSeed());
 expectError(jest.getSeed(123));
+
+expectType<boolean>(jest.isEnvironmentTornDown());
+expectError(jest.isEnvironmentTornDown(123));
